function [ret,x0,str,ts,xts]=a5gtosim(t,x,u,flag);
%A5GTOSIM	is the M-file description of the SIMULINK system named A5GTOSIM.
%	The block-diagram can be displayed by typing: A5GTOSIM.
%
%	SYS=A5GTOSIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes A5GTOSIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling A5GTOSIM with a FLAG of zero:
%	[SIZES]=A5GTOSIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[71,117,990,725])
     open_system(sys)
end;
set_param(sys,'BackGround',5)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '7')
set_param(sys,'Stop time',     '1699')
set_param(sys,'Min step size', '5')
set_param(sys,'Max step size', '5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['PHASE PROPULSEE DU LANCEUR ARIANE 5 G',13,'( Orbite vise :GTO )']])
set_param([sys,'/',['PHASE PROPULSEE DU LANCEUR ARIANE 5 G',13,'( Orbite vise :GTO )']],...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[390,0,395,5])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','poussee(u)/10000',...
		'Output Width','1',...
		'position',[370,133,430,167])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'BackGround',7,...
		'hide name',0,...
		'Initial','[0.1;pi/2-0.01;pi/2;0;0;0]',...
		'position',[595,62,630,118])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','100.000000',...
		'Hgain','1700.000000',...
		'Vmax','200.000000',...
		'Hmax','3400.000000',...
		'Window',[8,29,431,456])
open_system([sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'position',[495,135,525,165])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(4)/1000',...
		'Output Width','1',...
		'position',[710,133,770,167])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','Z',...
		'position',[810,172,860,188])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','VR',...
		'position',[810,112,860,128])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','ariane5(u)',...
		'Output Width','6',...
		'Mask Display','SYSTEME\nDIFFERENTIEL',...
		'position',[375,68,525,112])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(1)/1000',...
		'Output Width','1',...
		'position',[705,73,765,107])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn4'])
set_param([sys,'/','MATLAB Fcn4'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','(poussee(u)-trainee(u))/masse(u(7))',...
		'Output Width','1',...
		'position',[375,193,435,227])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn6'])
set_param([sys,'/','MATLAB Fcn6'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','(assiette(u)-u(2))*180/pi',...
		'Output Width','1',...
		'position',[380,238,440,272])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn7'])
set_param([sys,'/','MATLAB Fcn7'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','trainee(u)',...
		'Output Width','1',...
		'position',[380,283,440,317])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn5'])
set_param([sys,'/','MATLAB Fcn5'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','assiette(u)*180/pi',...
		'Output Width','1',...
		'position',[380,328,440,362])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn12'])
set_param([sys,'/','MATLAB Fcn12'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','0.5*u(1)^2*dens_atm(u(4))/1000',...
		'Output Width','1',...
		'position',[380,373,440,407])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','beta',...
		'position',[810,232,860,248])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn8'])
set_param([sys,'/','MATLAB Fcn8'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(3)*180/pi',...
		'Output Width','1',...
		'position',[710,193,770,227])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn9'])
set_param([sys,'/','MATLAB Fcn9'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(2)*180/pi',...
		'Output Width','1',...
		'position',[715,253,775,287])

add_block('built-in/Scope',[sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','50.000000',...
		'Hgain','1700.000000',...
		'Vmax','100.000000',...
		'Hmax','3400.000000',...
		'Window',[16,23,439,450],...
		'position',[825,255,855,285])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','gam',...
		'position',[820,292,870,308])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','acc_stat',...
		'position',[485,198,560,222])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','poussee',...
		'position',[485,168,560,192])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','incidence',...
		'position',[490,243,565,267])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','trainee',...
		'position',[490,288,565,312])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','assiette',...
		'position',[490,333,565,357])

add_block('built-in/To Workspace',[sys,'/','To Workspace11'])
set_param([sys,'/','To Workspace11'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','pression_dynamique',...
		'position',[490,378,610,402])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'BackGround',7,...
		'hide name',0,...
		'inputs','[6;1]',...
		'position',[295,70,325,110])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','1700.000000',...
		'Vmax','180.000000',...
		'Hmax','3400.000000',...
		'Window',[13,287,436,714],...
		'position',[825,195,855,225])

add_block('built-in/Clock',[sys,'/','temps'])
set_param([sys,'/','temps'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[160,88,185,112])

add_block('built-in/Note',[sys,'/','NB1: DONNEES MASSIQUES dans la fonction y = masse(t)'])
set_param([sys,'/','NB1: DONNEES MASSIQUES dans la fonction y = masse(t)'],...
		'ForeGround',5,...
		'position',[215,420,220,425])

add_block('built-in/Note',[sys,'/','NB2: Donnes arodynamiques dans la fonction y=trainee (u)'])
set_param([sys,'/','NB2: Donnes arodynamiques dans la fonction y=trainee (u)'],...
		'ForeGround',5,...
		'position',[215,440,220,445])

add_block('built-in/Note',[sys,'/','NB3 : Donnes sur les pousses et la chronologie dans la fonction y=poussee(u)'])
set_param([sys,'/','NB3 : Donnes sur les pousses et la chronologie dans la fonction y=poussee(u)'],...
		'ForeGround',5,...
		'position',[270,460,275,465])

add_block('built-in/Note',[sys,'/',['NB4 ; Donne de l''assiette locale dans la fonction y= assiette(t)']])
set_param([sys,'/',['NB4 ; Donne de l''assiette locale dans la fonction y= assiette(t)']],...
		'ForeGround',5,...
		'position',[220,480,225,485])

add_block('built-in/Note',[sys,'/','Mu=6640 kg, DVprop=11859=VR+DVpil+DVpes+DVtrainee=8459+279+2908+212'])
set_param([sys,'/','Mu=6640 kg, DVprop=11859=VR+DVpil+DVpes+DVtrainee=8459+279+2908+212'],...
		'Font Size',16,...
		'position',[390,555,395,560])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn10'])
set_param([sys,'/','MATLAB Fcn10'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(5)*180/pi',...
		'Output Width','1',...
		'position',[715,313,775,347])

add_block('built-in/Scope',[sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','100.000000',...
		'Hgain','1700.000000',...
		'Vmax','200.000000',...
		'Hmax','3400.000000',...
		'Window',[0,75,423,502],...
		'position',[825,315,855,345])

add_block('built-in/To Workspace',[sys,'/','To Workspace15'])
set_param([sys,'/','To Workspace15'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','L',...
		'position',[820,352,870,368])

add_block('built-in/To Workspace',[sys,'/','To Workspace16'])
set_param([sys,'/','To Workspace16'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','lamb',...
		'position',[825,412,875,428])

add_block('built-in/Scope',[sys,'/','Scope6'])
set_param([sys,'/','Scope6'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','1700.000000',...
		'Vmax','180.000000',...
		'Hmax','3400.000000',...
		'Window',[0,341,423,768],...
		'position',[830,375,860,405])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn13'])
set_param([sys,'/','MATLAB Fcn13'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(6)*180/pi',...
		'Output Width','1',...
		'position',[720,373,780,407])

add_block('built-in/Scope',[sys,'/','Scope7'])
set_param([sys,'/','Scope7'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','1800.000000',...
		'Hgain','1700.000000',...
		'Vmax','3600.000000',...
		'Hmax','3400.000000',...
		'Window',[8,333,431,760])
open_system([sys,'/','Scope7'])
set_param([sys,'/','Scope7'],...
		'position',[825,135,855,165])

add_block('built-in/Note',[sys,'/',['Atmosphre, vitesse du son, masse volumique, pression de l''air dans les fonctions pression, dens_atm, ']])
set_param([sys,'/',['Atmosphre, vitesse du son, masse volumique, pression de l''air dans les fonctions pression, dens_atm, ']],...
		'ForeGround',5,...
		'position',[335,505,340,510])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn11'])
set_param([sys,'/','MATLAB Fcn11'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','stop_gto(u)',...
		'Output Width','1',...
		'position',[730,453,790,487])

add_block('built-in/Stop Simulation',[sys,'/','Stop Simulation'])
set_param([sys,'/','Stop Simulation'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[825,453,865,487])

add_block('built-in/Scope',[sys,'/','Scope9'])
set_param([sys,'/','Scope9'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','1700.000000',...
		'Vmax','180.000000',...
		'Hmax','3400.000000',...
		'Window',[12,24,435,451])
open_system([sys,'/','Scope9'])
set_param([sys,'/','Scope9'],...
		'position',[835,495,865,525])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','temps',...
		'position',[275,117,325,133])

add_block('built-in/Scope',[sys,'/','Scope8'])
set_param([sys,'/','Scope8'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','1600.000000',...
		'Vmax','180.000000',...
		'Hmax','3200.000000',...
		'Window',[12,75,435,502],...
		'position',[255,140,285,170])

add_block('built-in/To Workspace',[sys,'/','To Workspace10'])
set_param([sys,'/','To Workspace10'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','teta_gam',...
		'buffer','1200',...
		'position',[210,185,310,205])

add_block('built-in/Note',[sys,'/','Injection vers 1798 km'])
set_param([sys,'/','Injection vers 1798 km'],...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[410,525,415,530])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','12.000000',...
		'Hgain','1700.000000',...
		'Vmax','24.000000',...
		'Hmax','3400.000000',...
		'Window',[-3,71,420,498],...
		'position',[820,75,850,105])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,42,1012,756])

add_block('built-in/Integrator',[sys,'/','Subsystem/Integrator1'])
set_param([sys,'/','Subsystem/Integrator1'],...
		'BackGround',7,...
		'hide name',0,...
		'Initial','[0;0;0;0]',...
		'position',[240,142,275,198])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn10'])
set_param([sys,'/','Subsystem/MATLAB Fcn10'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','pertes(u)',...
		'Output Width','4',...
		'Mask Display','SYSTEME\nDIFFERENTIEL',...
		'position',[60,148,210,192])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn16'])
set_param([sys,'/','Subsystem/MATLAB Fcn16'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(4)',...
		'Output Width','1',...
		'position',[335,78,395,112])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn15'])
set_param([sys,'/','Subsystem/MATLAB Fcn15'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(2)',...
		'Output Width','1',...
		'position',[335,118,395,152])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn14'])
set_param([sys,'/','Subsystem/MATLAB Fcn14'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(3)',...
		'Output Width','1',...
		'position',[335,158,395,192])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn13'])
set_param([sys,'/','Subsystem/MATLAB Fcn13'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(1)',...
		'Output Width','1',...
		'position',[335,203,395,237])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[425,85,445,105])

add_block('built-in/Outport',[sys,'/','Subsystem/out_2'])
set_param([sys,'/','Subsystem/out_2'],...
		'Port','2',...
		'position',[425,125,445,145])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[10,160,30,180])

add_block('built-in/Outport',[sys,'/','Subsystem/out_4'])
set_param([sys,'/','Subsystem/out_4'],...
		'Port','4',...
		'position',[425,210,445,230])

add_block('built-in/Outport',[sys,'/','Subsystem/out_3'])
set_param([sys,'/','Subsystem/out_3'],...
		'Port','3',...
		'position',[425,165,445,185])
add_line([sys,'/','Subsystem'],[280,170;315,170;315,175;330,175])
add_line([sys,'/','Subsystem'],[315,170;315,220;330,220])
add_line([sys,'/','Subsystem'],[315,175;315,135;330,135])
add_line([sys,'/','Subsystem'],[315,135;315,95;330,95])
add_line([sys,'/','Subsystem'],[215,170;235,170])
add_line([sys,'/','Subsystem'],[400,95;420,95])
add_line([sys,'/','Subsystem'],[400,135;420,135])
add_line([sys,'/','Subsystem'],[35,170;55,170])
add_line([sys,'/','Subsystem'],[400,175;420,175])
add_line([sys,'/','Subsystem'],[400,220;420,220])
set_param([sys,'/','Subsystem'],...
		'Mask Display','PERTES\net\nPROPULSION')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'position',[115,257,230,373])

add_block('built-in/To Workspace',[sys,'/','To Workspace12'])
set_param([sys,'/','To Workspace12'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'mat-name','DVpes',...
		'position',[255,318,330,342])

add_block('built-in/To Workspace',[sys,'/','To Workspace13'])
set_param([sys,'/','To Workspace13'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'mat-name','DVpil',...
		'position',[255,288,330,312])

add_block('built-in/To Workspace',[sys,'/','To Workspace14'])
set_param([sys,'/','To Workspace14'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'mat-name','DVtrainee',...
		'position',[255,258,330,282])

add_block('built-in/To Workspace',[sys,'/','To Workspace17'])
set_param([sys,'/','To Workspace17'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'mat-name','DVprop',...
		'position',[255,348,330,372])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn14'])
set_param([sys,'/','MATLAB Fcn14'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','(assiette(u)-u(2))*180/pi',...
		'Output Width','1',...
		'position',[65,138,125,172])
add_line(sys,[635,90;700,90])
add_line(sys,[530,90;590,90])
add_line(sys,[655,90;655,415;40,415;40,80;290,80])
add_line(sys,[330,90;370,90])
add_line(sys,[190,100;290,100])
add_line(sys,[770,90;815,90])
add_line(sys,[675,90;675,150;705,150])
add_line(sys,[775,150;820,150])
add_line(sys,[770,90;770,120;805,120])
add_line(sys,[785,150;785,180;805,180])
add_line(sys,[220,100;220,125;270,125])
add_line(sys,[435,150;490,150])
add_line(sys,[435,150;440,150;480,180])
add_line(sys,[440,210;480,210])
add_line(sys,[340,90;340,150;365,150])
add_line(sys,[445,255;485,255])
add_line(sys,[340,150;340,255;375,255])
add_line(sys,[445,300;485,300])
add_line(sys,[675,150;675,210;705,210])
add_line(sys,[775,210;820,210])
add_line(sys,[790,210;790,240;805,240])
add_line(sys,[675,210;675,270;710,270])
add_line(sys,[780,270;820,270])
add_line(sys,[780,270;780,300;815,300])
add_line(sys,[340,220;340,345;375,345])
add_line(sys,[445,345;485,345])
add_line(sys,[340,345;340,390;375,390])
add_line(sys,[445,390;485,390])
add_line(sys,[340,210;370,210])
add_line(sys,[780,330;820,330])
add_line(sys,[780,330;780,360;815,360])
add_line(sys,[675,270;675,330;710,330])
add_line(sys,[785,390;825,390])
add_line(sys,[785,390;785,420;820,420])
add_line(sys,[675,270;675,390;715,390])
add_line(sys,[340,300;375,300])
add_line(sys,[340,220;50,220;60,155])
add_line(sys,[130,155;250,155])
add_line(sys,[130,155;190,195;205,195])
add_line(sys,[795,470;820,470])
add_line(sys,[675,390;675,470;725,470])
add_line(sys,[795,470;795,510;830,510])
add_line(sys,[235,360;250,360])
add_line(sys,[235,330;250,330])
add_line(sys,[235,270;250,270])
add_line(sys,[235,300;250,300])
add_line(sys,[50,220;50,315;110,315])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
