function [ret,x0,str,ts,xts]=pert_sim(t,x,u,flag);
%PERT_SIM	is the M-file description of the SIMULINK system named PERT_SIM.
%	The block-diagram can be displayed by typing: PERT_SIM.
%
%	SYS=PERT_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PERT_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PERT_SIM with a FLAG of zero:
%	[SIZES]=PERT_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,600,400])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[515,378,930,653])

add_block('built-in/Outport',[sys,'/','Subsystem/out_4'])
set_param([sys,'/','Subsystem/out_4'],...
		'Port','4',...
		'position',[425,210,445,230])

add_block('built-in/Outport',[sys,'/','Subsystem/out_3'])
set_param([sys,'/','Subsystem/out_3'],...
		'Port','3',...
		'position',[410,165,430,185])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[10,160,30,180])

add_block('built-in/Outport',[sys,'/','Subsystem/out_2'])
set_param([sys,'/','Subsystem/out_2'],...
		'Port','2',...
		'position',[425,125,445,145])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[425,85,445,105])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn13'])
set_param([sys,'/','Subsystem/MATLAB Fcn13'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(1)/1000',...
		'Output Width','1',...
		'position',[335,203,395,237])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn14'])
set_param([sys,'/','Subsystem/MATLAB Fcn14'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(3)/1000',...
		'Output Width','1',...
		'position',[335,158,395,192])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn15'])
set_param([sys,'/','Subsystem/MATLAB Fcn15'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(2)/1000',...
		'Output Width','1',...
		'position',[335,118,395,152])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn16'])
set_param([sys,'/','Subsystem/MATLAB Fcn16'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','u(4)/1000',...
		'Output Width','1',...
		'position',[335,78,395,112])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn10'])
set_param([sys,'/','Subsystem/MATLAB Fcn10'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','pertes(u)',...
		'Output Width','4',...
		'Mask Display','SYSTEME\nDIFFERENTIEL',...
		'position',[60,148,210,192])

add_block('built-in/Integrator',[sys,'/','Subsystem/Integrator1'])
set_param([sys,'/','Subsystem/Integrator1'],...
		'BackGround',7,...
		'hide name',0,...
		'Initial','[0;0;0;0]',...
		'position',[240,142,275,198])
add_line([sys,'/','Subsystem'],[400,220;420,220])
add_line([sys,'/','Subsystem'],[400,175;405,175])
add_line([sys,'/','Subsystem'],[35,170;55,170])
add_line([sys,'/','Subsystem'],[400,135;420,135])
add_line([sys,'/','Subsystem'],[400,95;420,95])
add_line([sys,'/','Subsystem'],[215,170;235,170])
add_line([sys,'/','Subsystem'],[280,170;315,170;315,175;330,175])
add_line([sys,'/','Subsystem'],[315,175;315,135;330,135])
add_line([sys,'/','Subsystem'],[315,135;315,95;330,95])
add_line([sys,'/','Subsystem'],[315,170;315,220;330,220])
set_param([sys,'/','Subsystem'],...
		'Mask Display','PERTES\net\nPROPULSION')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'position',[95,202,210,318])

add_block('built-in/To Workspace',[sys,'/','To Workspace12'])
set_param([sys,'/','To Workspace12'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'mat-name','DVpes',...
		'position',[235,263,310,287])

add_block('built-in/To Workspace',[sys,'/','To Workspace13'])
set_param([sys,'/','To Workspace13'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'mat-name','DVpil',...
		'position',[235,233,310,257])

add_block('built-in/To Workspace',[sys,'/','To Workspace14'])
set_param([sys,'/','To Workspace14'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'mat-name','DVtrainee',...
		'position',[235,203,310,227])

add_block('built-in/To Workspace',[sys,'/','To Workspace10'])
set_param([sys,'/','To Workspace10'],...
		'ForeGround',5,...
		'BackGround',4,...
		'hide name',0,...
		'mat-name','DVprop',...
		'position',[235,293,310,317])
add_line(sys,[215,305;230,305])
add_line(sys,[215,275;230,275])
add_line(sys,[215,215;230,215])
add_line(sys,[215,245;230,245])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
