function [ret,x0,str,ts,xts]=heli_sim(t,x,u,flag);
%HELI_SIM	is the M-file description of the SIMULINK system named HELI_SIM.
%	The block-diagram can be displayed by typing: HELI_SIM.
%
%	SYS=HELI_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes HELI_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling HELI_SIM with a FLAG of zero:
%	[SIZES]=HELI_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,1012,756])
     open_system(sys)
end;
set_param(sys,'BackGround',5)
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '7')
set_param(sys,'Stop time',     '1699')
set_param(sys,'Min step size', '5')
set_param(sys,'Max step size', '5')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn3'])
set_param([sys,'/','MATLAB Fcn3'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','poussee(u)/10000',...
		'Output Width','1',...
		'position',[370,133,430,167])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'BackGround',7,...
		'hide name',0,...
		'Initial','[0.1;pi/2-0.01;-0.05;0;-0.921;0.091]',...
		'position',[595,62,630,118])

add_block('built-in/Scope',[sys,'/','Scope2'])
set_param([sys,'/','Scope2'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','10000.000000',...
		'Hgain','1700.000000',...
		'Vmax','20000.000000',...
		'Hmax','3400.000000',...
		'Window',[13,287,436,714])
set_param([sys,'/','Scope2'],...
		'position',[495,135,525,165])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn2'])
set_param([sys,'/','MATLAB Fcn2'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(4)/1000',...
		'Output Width','1',...
		'position',[710,133,770,167])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','Z',...
		'position',[810,172,860,188])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','VR',...
		'position',[810,112,860,128])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn1'])
set_param([sys,'/','MATLAB Fcn1'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(1)/1000',...
		'Output Width','1',...
		'position',[705,73,765,107])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn4'])
set_param([sys,'/','MATLAB Fcn4'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','(poussee(u)-trainee(u))/masse(u(7))',...
		'Output Width','1',...
		'position',[375,193,435,227])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn6'])
set_param([sys,'/','MATLAB Fcn6'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','(assiette(u)-u(2))*180/pi',...
		'Output Width','1',...
		'position',[380,238,440,272])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn7'])
set_param([sys,'/','MATLAB Fcn7'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','trainee(u)',...
		'Output Width','1',...
		'position',[380,283,440,317])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn5'])
set_param([sys,'/','MATLAB Fcn5'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','assiette(u)*180/pi',...
		'Output Width','1',...
		'position',[380,328,440,362])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn12'])
set_param([sys,'/','MATLAB Fcn12'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','0.5*u(1)^2*dens_atm(u(4))/1000',...
		'Output Width','1',...
		'position',[380,373,440,407])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn8'])
set_param([sys,'/','MATLAB Fcn8'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(3)*180/pi',...
		'Output Width','1',...
		'position',[710,193,770,227])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn9'])
set_param([sys,'/','MATLAB Fcn9'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(2)*180/pi',...
		'Output Width','1',...
		'position',[715,253,775,287])

add_block('built-in/Scope',[sys,'/','Scope4'])
set_param([sys,'/','Scope4'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','50.000000',...
		'Hgain','1700.000000',...
		'Vmax','100.000000',...
		'Hmax','3400.000000',...
		'Window',[507,341,930,768],...
		'position',[825,255,855,285])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','gam',...
		'position',[820,292,870,308])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','acc_stat',...
		'position',[485,198,560,222])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','poussee',...
		'position',[485,168,560,192])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','incidence',...
		'position',[490,243,565,267])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','trainee',...
		'position',[490,288,565,312])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','assiette',...
		'position',[490,333,565,357])

add_block('built-in/To Workspace',[sys,'/','To Workspace11'])
set_param([sys,'/','To Workspace11'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','pression_dynamique',...
		'position',[490,378,610,402])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'BackGround',6,...
		'hide name',0,...
		'inputs','[6;1]',...
		'position',[295,70,325,110])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'position',[275,127,325,143])

add_block('built-in/Note',[sys,'/','Injection vers 822 km'])
set_param([sys,'/','Injection vers 822 km'],...
		'Font Name','Arial',...
		'Font Size',16,...
		'position',[185,345,190,350])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn10'])
set_param([sys,'/','MATLAB Fcn10'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(5)*180/pi',...
		'Output Width','1',...
		'position',[715,313,775,347])

add_block('built-in/Scope',[sys,'/','Scope5'])
set_param([sys,'/','Scope5'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','100.000000',...
		'Hgain','1700.000000',...
		'Vmax','200.000000',...
		'Hmax','3400.000000',...
		'Window',[0,75,423,502],...
		'position',[825,315,855,345])

add_block('built-in/To Workspace',[sys,'/','To Workspace15'])
set_param([sys,'/','To Workspace15'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','L',...
		'position',[820,352,870,368])

add_block('built-in/To Workspace',[sys,'/','To Workspace16'])
set_param([sys,'/','To Workspace16'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lamb',...
		'position',[825,412,875,428])

add_block('built-in/Scope',[sys,'/','Scope6'])
set_param([sys,'/','Scope6'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','1700.000000',...
		'Vmax','180.000000',...
		'Hmax','3400.000000',...
		'Window',[0,341,423,768],...
		'position',[830,375,860,405])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn13'])
set_param([sys,'/','MATLAB Fcn13'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u(6)*180/pi',...
		'Output Width','1',...
		'position',[720,373,780,407])

add_block('built-in/Scope',[sys,'/','Scope7'])
set_param([sys,'/','Scope7'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','1800.000000',...
		'Hgain','1700.000000',...
		'Vmax','3600.000000',...
		'Hmax','3400.000000',...
		'Window',[43,341,466,768])
open_system([sys,'/','Scope7'])
set_param([sys,'/','Scope7'],...
		'position',[825,135,855,165])

add_block('built-in/Scope',[sys,'/','Scope8'])
set_param([sys,'/','Scope8'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','1600.000000',...
		'Vmax','180.000000',...
		'Hmax','3200.000000',...
		'Window',[12,75,435,502],...
		'position',[255,270,285,300])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','10.000000',...
		'Hgain','1700.000000',...
		'Vmax','20.000000',...
		'Hmax','3400.000000',...
		'Window',[42,17,465,444])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[815,75,845,105])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn14'])
set_param([sys,'/','MATLAB Fcn14'],...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','(assiette(u)-u(2))*180/pi',...
		'Output Width','1',...
		'position',[110,268,170,302])

add_block('built-in/To Workspace',[sys,'/','To Workspace10'])
set_param([sys,'/','To Workspace10'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','teta_gam',...
		'buffer','1200',...
		'position',[210,315,310,335])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','arian5(u)',...
		'Output Width','7',...
		'Mask Display','SYSTEME\nDIFFERENTIEL',...
		'position',[365,66,465,114])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','beta',...
		'position',[805,232,855,248])

add_block('built-in/Scope',[sys,'/','Scope3'])
set_param([sys,'/','Scope3'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','40.000000',...
		'Hgain','1700.000000',...
		'Vmax','80.000000',...
		'Hmax','3400.000000',...
		'Window',[375,19,798,446],...
		'position',[820,195,850,225])

add_block('built-in/To Workspace',[sys,'/','To Workspace12'])
set_param([sys,'/','To Workspace12'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','controle',...
		'position',[595,162,645,178])

add_block('built-in/Scope',[sys,'/','Scope9'])
set_param([sys,'/','Scope9'],...
		'BackGround',3,...
		'hide name',0,...
		'Vgain','3.000000',...
		'Hgain','1700.000000',...
		'Vmax','6.000000',...
		'Hmax','3400.000000',...
		'Window',[557,29,980,456],...
		'position',[610,125,640,155])

add_block('built-in/Note',[sys,'/',['PHASE PROPULSEE DU LANCEUR ARIANE 5G',13,'(Orbite vise :HELIOSYNCHRONE)']])
set_param([sys,'/',['PHASE PROPULSEE DU LANCEUR ARIANE 5G',13,'(Orbite vise :HELIOSYNCHRONE)']],...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[390,0,395,5])

add_block('built-in/Clock',[sys,'/','temps'])
set_param([sys,'/','temps'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[155,85,185,115])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn11'])
set_param([sys,'/','MATLAB Fcn11'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','stop_hel(u)',...
		'Output Width','1',...
		'position',[135,143,195,177])

add_block('built-in/Stop Simulation',[sys,'/','Stop Simulation'])
set_param([sys,'/','Stop Simulation'],...
		'BackGround',7,...
		'hide name',0,...
		'position',[230,143,270,177])

add_block('built-in/Scope',[sys,'/','Scope10'])
set_param([sys,'/','Scope10'],...
		'BackGround',7,...
		'hide name',0,...
		'Vgain','90.000000',...
		'Hgain','1700.000000',...
		'Vmax','180.000000',...
		'Hmax','3400.000000',...
		'Window',[13,197,436,622],...
		'position',[240,185,270,215])

add_block('built-in/Note',[sys,'/',['Atmosphre, vitesse du son, masse volumique, pression de l''air dans les fonctions pression, dens_atm, ']])
set_param([sys,'/',['Atmosphre, vitesse du son, masse volumique, pression de l''air dans les fonctions pression, dens_atm, ']],...
		'ForeGround',5,...
		'position',[350,600,355,605])

add_block('built-in/Note',[sys,'/',['NB4 ; Donne de l''assiette locale dans la fonction y= assiette(t)']])
set_param([sys,'/',['NB4 ; Donne de l''assiette locale dans la fonction y= assiette(t)']],...
		'ForeGround',5,...
		'position',[235,580,240,585])

add_block('built-in/Note',[sys,'/','NB3 : Donnes sur les pousses et la chronologie dans la fonction y=poussee(u)'])
set_param([sys,'/','NB3 : Donnes sur les pousses et la chronologie dans la fonction y=poussee(u)'],...
		'ForeGround',5,...
		'position',[285,560,290,565])

add_block('built-in/Note',[sys,'/','NB1: DONNEES MASSIQUES dans la fonction y = masse(t)'])
set_param([sys,'/','NB1: DONNEES MASSIQUES dans la fonction y = masse(t)'],...
		'ForeGround',5,...
		'position',[225,525,230,530])

add_block('built-in/Note',[sys,'/','NB2: Donnes arodynamiques dans la fonction y=trainee (u)'])
set_param([sys,'/','NB2: Donnes arodynamiques dans la fonction y=trainee (u)'],...
		'ForeGround',5,...
		'position',[230,545,235,550])

add_block('built-in/Demux',[sys,'/','Demux'])
set_param([sys,'/','Demux'],...
		'ForeGround',4,...
		'BackGround',6,...
		'outputs','[6;1]',...
		'position',[480,70,540,105])

add_block('built-in/To Workspace',[sys,'/','To Workspace20'])
set_param([sys,'/','To Workspace20'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','dvtrain',...
		'position',[790,542,840,558])

add_block('built-in/To Workspace',[sys,'/','To Workspace19'])
set_param([sys,'/','To Workspace19'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','dvpes',...
		'position',[785,517,835,533])

add_block('built-in/To Workspace',[sys,'/','To Workspace18'])
set_param([sys,'/','To Workspace18'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','dvpil',...
		'position',[785,492,835,508])

add_block('built-in/To Workspace',[sys,'/','To Workspace17'])
set_param([sys,'/','To Workspace17'],...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','dvprop',...
		'position',[785,467,835,483])

add_block('built-in/Demux',[sys,'/','Demux1'])
set_param([sys,'/','Demux1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'outputs','[1;1;1;1]',...
		'position',[690,464,740,561])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn15'])
set_param([sys,'/','MATLAB Fcn15'],...
		'BackGround',7,...
		'hide name',0,...
		'MATLAB Fcn','pertes(u)',...
		'Output Width','4',...
		'Mask Display','SYSTEME\nDIFFERENTIEL',...
		'position',[435,491,535,539])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'BackGround',7,...
		'hide name',0,...
		'Initial','[0;0;0;0]',...
		'position',[610,487,645,543])

add_block('built-in/Note',[sys,'/','Mu=9800 kg, DVprop=10908=VR+DVpil+DVpes+DVtrainee=7478+392+2834.5+203.5'])
set_param([sys,'/','Mu=9800 kg, DVprop=10908=VR+DVpil+DVpes+DVtrainee=7478+392+2834.5+203.5'],...
		'Font Size',16,...
		'position',[470,650,475,655])
add_line(sys,[635,90;700,90])
add_line(sys,[655,90;655,415;40,415;40,75;290,80])
add_line(sys,[330,90;360,90])
add_line(sys,[190,100;290,100])
add_line(sys,[770,90;810,90])
add_line(sys,[675,90;675,150;705,150])
add_line(sys,[775,150;820,150])
add_line(sys,[770,90;770,120;805,120])
add_line(sys,[785,150;785,180;805,180])
add_line(sys,[220,100;220,135;270,135])
add_line(sys,[435,150;490,150])
add_line(sys,[435,150;440,150;480,180])
add_line(sys,[440,210;480,210])
add_line(sys,[330,90;340,90;340,150;365,150])
add_line(sys,[445,255;485,255])
add_line(sys,[340,150;340,255;375,255])
add_line(sys,[445,300;485,300])
add_line(sys,[675,150;675,210;705,210])
add_line(sys,[775,210;815,210])
add_line(sys,[775,210;790,210;800,240])
add_line(sys,[675,210;675,270;710,270])
add_line(sys,[780,270;820,270])
add_line(sys,[780,270;780,300;815,300])
add_line(sys,[340,220;340,345;375,345])
add_line(sys,[445,345;485,345])
add_line(sys,[340,345;340,390;375,390])
add_line(sys,[445,390;485,390])
add_line(sys,[340,210;370,210])
add_line(sys,[780,330;820,330])
add_line(sys,[780,330;780,360;815,360])
add_line(sys,[675,270;675,330;710,330])
add_line(sys,[785,390;825,390])
add_line(sys,[785,390;785,420;820,420])
add_line(sys,[675,270;675,390;715,390])
add_line(sys,[340,300;375,300])
add_line(sys,[340,220;95,220;105,285])
add_line(sys,[175,285;250,285])
add_line(sys,[175,285;190,285;190,325;205,325])
add_line(sys,[470,90;475,90])
add_line(sys,[545,80;560,80;560,90;590,90])
add_line(sys,[545,95;550,95;550,140;605,140])
add_line(sys,[570,140;570,170;590,170])
add_line(sys,[200,160;225,160])
add_line(sys,[200,160;200,200;235,200])
add_line(sys,[95,220;95,160;130,160])
add_line(sys,[340,390;340,515;430,515])
add_line(sys,[650,515;685,515])
add_line(sys,[745,475;780,475])
add_line(sys,[745,500;780,500])
add_line(sys,[745,525;780,525])
add_line(sys,[745,550;785,550])
add_line(sys,[540,515;605,515])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
